@@ -38,7 +38,7 @@ use constant ETHER2TOKEN => (
 
 use base qw( Exporter );
 use vars qw( $VERSION %EXPORT_TAGS @EXPORT_OK );
-$VERSION = (qw$Revision: 0.92 $)[1];
+$VERSION = (qw$Revision: 0.93 $)[1];
 
 %EXPORT_TAGS = (
     all => [
@@ -318,8 +318,8 @@ sub new {
               ; # blindly remove the prefix from bpr, we could check that \d is the actual length, but oh well
 
             # avoid matching ipv6
-            last if $mac =~ m/[a-f0-9]{4}:[a-f0-9]{4}::([a-f0-9]{4})?/i;
-            last if $mac =~ m/[a-f0-9]{4}::[a-f0-9]{4}:[a-f0-9]{4}/i;
+            last if $mac =~ m/[a-f0-9]{1,4}:[a-f0-9]{1,4}::([a-f0-9]{1,4})?/i;
+            last if $mac =~ m/[a-f0-9]{1,4}::[a-f0-9]{1,4}:[a-f0-9]{1,4}/i;
 
             my @parts = grep { length } split( /[^a-z0-9]+/ix, $mac );
 
